@@ -5,12 +5,23 @@ from typing import Optional
 from urllib.parse import urlencode, urljoin
 
 import aiohttp
+import requests
+from hubble.client.session import HubbleAPISession
 from hubble.utils.api_utils import get_base_url
 from hubble.utils.config import config
 from rich import print
 
 
 class Auth:
+    @staticmethod
+    def get_auth_token_from_config():
+        """Get user auth token from config file."""
+        token_from_config: Optional[str] = None
+        if isinstance(config.get('auth_token'), str):
+            token_from_config = config.get('auth_token')
+
+        return token_from_config
+
     @staticmethod
     def get_auth_token():
         """Get user auth token.
@@ -20,14 +31,25 @@ class Auth:
         """
         token_from_env = os.environ.get('JINA_AUTH_TOKEN')
 
-        token_from_config: Optional[str] = None
-        if isinstance(config.get('auth_token'), str):
-            token_from_config = config.get('auth_token')
+        token_from_config: Optional[str] = Auth.get_auth_token_from_config()
 
         return token_from_env if token_from_env else token_from_config
 
     @staticmethod
-    async def login(**kwargs):
+    async def login(force=False, **kwargs):
+        # verify if token already exists, authenticate token if exists
+        if not force:
+            token = Auth.get_auth_token()
+            if token:
+                session = HubbleAPISession()
+                session.init_jwt_auth(token)
+                try:
+                    resp = session.validate_token()
+                    resp.raise_for_status()
+                    return
+                except requests.exceptions.HTTPError:
+                    pass
+
         api_host = get_base_url()
         auth_info = None
         async with aiohttp.ClientSession(trust_env=True) as session:
@@ -80,6 +102,13 @@ class Auth:
                 user = json_response['data']['user']['nickname']
 
                 config.set('auth_token', token)
+
+                from hubble.dockerauth import (
+                    auto_deploy_hubble_docker_credential_helper,
+                )
+
+                auto_deploy_hubble_docker_credential_helper()
+
                 print(
                     f':closed_lock_with_key: [green]Successfully logged in to Jina AI[/] as [b]{user}[/b]!'
                 )
@@ -88,8 +117,13 @@ class Auth:
     async def logout():
         api_host = get_base_url()
 
+        token = Auth.get_auth_token()
+        token_from_config = Auth.get_auth_token_from_config()
+        if token != token_from_config:
+            print(':warning: The token from environment variable is ignored.')
+
         async with aiohttp.ClientSession(trust_env=True) as session:
-            session.headers.update({'Authorization': f'token {Auth.get_auth_token()}'})
+            session.headers.update({'Authorization': f'token {token_from_config}'})
 
             async with session.post(
                 url=urljoin(api_host, 'user.session.dismiss')
@@ -97,7 +131,7 @@ class Auth:
                 json_response = await response.json()
                 if json_response['code'] == 401:
                     print(
-                        ':unlock: You are not logged in. There is no need to log out.'
+                        ':unlock: You are not logged in locally. There is no need to log out.'
                     )
                 elif json_response['code'] == 200:
                     print(':unlock: You have successfully logged out.')
